/**
 * ログインIDとパスワードを Cookie とやり取りする。
 * <pre>
 * ログインフォームの要素名は、
 * 　ログインID == loginid
 * 　パスワード == password
 * 　ログインを記録する == rememberme
 * でなければならない。
 * </pre>
 */
/**
 * Cookie から、ログイン情報を取得し、フォームにセットする。
 * <pre>
 * body の、onload で呼ばれることを想定している。
 * </pre>
 * @param frm ログインフォーム
 * @return void
 */
function setLoginParamFromCookie(frm, defaultid, defaultpsw)
{
	try
	{
		// cookie から、loginid を得る
		document.cookie.match(/loginid=([^;]+)/);
		frm.loginid.value = RegExp.$1;
		if (frm.loginid.value == "")
		{
			frm.loginid.value = defaultid;
		}

		// cookie から、password を得る
		document.cookie.match(/password=([^;]+)/);
		frm.password.value = RegExp.$1;
		if (frm.password.value == "")
		{
			frm.password.value = defaultpsw;
		}

		// ログインID, パスワードがセットされていれば、ログインを記録するチェックボックスを ON にする。
		if (frm.loginid.value != "" && frm.loginid.value != defaultid
		 && frm.password.value != "" && frm.password.value != defaultpsw)
		{
			frm.rememberme.checked = true;
		}
	}
	catch(e)
	{
		alert(e);
	}
}
/**
 * ログイン情報を Cookie に保存する。
 * <pre>
 * loginid, password がセットされており、ログインを記録するがONのとき、
 * クッキーに保存する。
 * ログインを記録するが、OFF のときはクッキーを削除する。
 * loginid, password がセットされていない場合は、フォームをサブミットさせない。
 * </pre>
 * @param frm ログインフォーム
 * @return loginid, password がセットされているとき、true。それ以外 false。
 */
function setLoginParam2Cookie(frm)
{
	try
	{
		if ((frm.loginid.value != "") && (frm.password.value != ""))
		{
			if (frm.rememberme.checked)
			{
				document.cookie = "loginid="
								+ frm.loginid.value
								+ ";password="
								+ frm.password.value
								+ ";expires=Tue, 1-Jan-2030 00:00:00 GMT";
			}
			else
			{
				document.cookie = "loginid=;password=;expires=;";
			}
			return true; 
		}
		return false;
	}
	catch(e)
	{
		alert(e);
		return false;
	}
	return false;
}
